==> haskell-ghc-exactprint-1.6.1-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-exactprint
version:              1.6.1
visibility:           public
id:                   ghc-exactprint-1.6.1-CgVB5jPJvSD4i741Pz0XRE
key:                  ghc-exactprint-1.6.1-CgVB5jPJvSD4i741Pz0XRE
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 9.2.1, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    Note: requires GHC 9.4.*. For earlier GHC
    versions see lower version numbers.

category:             Development
abi:                  dbab0835a8210f34923a046bb422794d
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Dump
    Language.Haskell.GHC.ExactPrint.ExactPrint
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Orphans
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-exactprint
hs-libraries:         HSghc-exactprint-1.6.1-CgVB5jPJvSD4i741Pz0XRE
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-7mS5xpY4EnxodGGT6vPB1 directory-1.3.7.1
    filepath-1.4.2.2 free-5.2-3lxHOZ3HA538Pa6VHTjVaM ghc-9.4.8
    ghc-boot-9.4.8 mtl-2.2.2
    ordered-containers-0.2.4-ZKctI5SuFAAtJYPeVEJd7
    syb-0.7.2.4-BoBt6NiEdTQJ1wn7K7eKAO

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-exactprint-1.6.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-exactprint
version:              1.6.1
visibility:           public
id:                   ghc-exactprint-1.6.1-BnsKO65q4y96WOjE7IeOBL
key:                  ghc-exactprint-1.6.1-BnsKO65q4y96WOjE7IeOBL
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 9.2.1, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    Note: requires GHC 9.4.*. For earlier GHC
    versions see lower version numbers.

category:             Development
abi:                  5e969d468d5be04f55927d50a326dc0a
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Dump
    Language.Haskell.GHC.ExactPrint.ExactPrint
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Orphans
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-exactprint-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-exactprint
hs-libraries:         HSghc-exactprint-1.6.1-BnsKO65q4y96WOjE7IeOBL
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-7mS5xpY4EnxodGGT6vPB1 directory-1.3.7.1
    filepath-1.4.2.2 free-5.2-TrLvtrA0gM2voGgcmOMXy ghc-9.4.8
    ghc-boot-9.4.8 mtl-2.2.2
    ordered-containers-0.2.4-Gn0GOn2xvkzEGrvWPEx3Fy
    syb-0.7.2.4-CLsCb1U1DGkGwwvmeMNNEv

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
